import React, { useRef, useState, useEffect } from 'react'
import List from '@/components/Page/List'
import { Button, Tag, Image, Typography, Popconfirm } from 'antd'
import { useNavigate } from 'react-router-dom'
import dayjs from 'dayjs';
import { queryDict } from "@/utils/request";
import { getTaPost, deleteTaPost, putTaPost } from "@/services/taPost";
import { getTdCategory } from "@/services/tdCategory";

const { Text } = Typography;

const queryCategory = queryDict(getTdCategory, { labelKey: "categoryName", valueKey: "categoryId" })

export default (props) => {
  const [categoryList, setCategoryList] = useState()
  const actionRef = useRef();
  const navigate = useNavigate();

  const columns = [
    {
      title: "创建时间",
      dataIndex: "createdTime",
      valueType: "dateRange",
      render: (_, it) => it.createdTime?.replace("T", " ").replace(/\d+\:\d+\:\d+/, ""),
      hideInTable: true,
      search: {
        transform: (val) => {
          return {
            startDate: val[0],
            endDate: val[1],
          };
        },
      }
    },
    {
      title: '标题',
      dataIndex: 'title',
      render: (_, it) => <Text key="title" ellipsis={true}>{it?.title}</Text>,
    },
    {
      title: '描述',
      dataIndex: 'describe',
      render: (_, it) => <Text key="describe" ellipsis={true}>{it?.describe}</Text>,
      search: false,
    },
    {
      title: '正文',
      dataIndex: 'content',
      render: (_, it) => <Text key="content" style={{ width: 200 }} ellipsis={true}>{it?.content?.replace(/<[^>]+>/g, '')}</Text>,
      search: false,
    },
    {
      title: '图片',
      dataIndex: 'images',
      render: (_, it) => it?.images ? <Text key="images" style={{ width: 100 }} ellipsis={true}><Image src={`${prefix}` + JSON.parse(it?.images)[0]} height={60} /></Text> : null,
      search: false,
    },
    {
      title: '分类',
      dataIndex: 'categoryId',
      valueType: 'select',
      request: queryCategory
    },
    // {
    //   title: '横向封面',
    //   dataIndex: 'coverHorizontal',
    //   render: (_, it) => it?.coverHorizontal ? <Image src={`${prefix}` + it?.coverHorizontal} width={80} /> : null,
    //   search: false,
    // },
    // {
    //   title: '纵向封面',
    //   dataIndex: 'coverVertical',
    //   render: (_, it) => it?.coverVertical ? <Image src={`${prefix}` + it?.coverVertical} width={80} /> : null,
    //   search: false,
    // },
    {
      title: '标签',
      dataIndex: 'tags',
      search: false,
      render: (_, it) => it?.tags ? <Text key="tags" style={{ width: 140 }} ellipsis={true}>{JSON.parse(it?.tags).map(it => <Tag color="processing">{it}</Tag>)}</Text> : null
    },
    {
      title: '作者',
      dataIndex: 'author',
      render: (_, it) => <Text key="author" style={{ width: 100 }} ellipsis={true}>{it?.author}</Text>,
    },
    {
      title: '链接',
      dataIndex: 'link',
      render: (_, it) => <Text key="link" style={{ width: 100 }} ellipsis={true}><a href={it?.link} target="_bank">{it?.link}</a></Text>,
      search: false,
    },
    {
      title: '状态',
      dataIndex: 'status',
      valueEnum: {
        0: '未发布',
        1: '发布'
      },
      search: false,
    },
    {
      title: '创建时间',
      dataIndex: 'createdTime',
      render: (_, it) => dayjs(it?.createdTime).format('YYYY-MM-DD HH:mm'),
      search: false,
    }
  ]

  const onEdit = (it) => {
    navigate(`/article/edit?id=${it.postId}`)
  }

  const onDelete = (it) => {
    deleteTaPost(it.postId).then(res => {
      actionRef.current.reload();
    })
  }
  useEffect(() => {
    getTdCategory().then((res) => {
      let data = res?.records.map(x => ({ categoryName: x.categoryName, categoryId: x.categoryId }))
      setCategoryList(data)
    })
  }, [])

  const onDetail = (it) => {
    navigate(`/article/detail?id=${it.postId}`)
  }

  const onRelease = (item) => {
    let status = item.status === 1 ? 0 : 1
    let id = item.postId
    let cName = categoryList.find(item => item.categoryId === item?.categoryId)
    let data = [item].map(item => {
      const { createdTime, updatedTime, ...rest } = item
      return { ...rest, status: status, categoryName: cName.categoryName }
    })

    // console.log('--------categoryList------------->', categoryList);
    putTaPost(id, data[0]).then(res => {
      actionRef.current?.reload()
    })
  }

  return (
    <List
      rowKey="postId"
      columns={columns}
      actionRef={actionRef}
      onEdit={onEdit}
      onDelete={onDelete}
      // onDetail={onDetail}
      request={getTaPost}
      toolBarRender={() => [
        <Button
          key="2"
          type="primary"
          onClick={() => {
            navigate('/article/edit')
          }}
        >
          新增
        </Button>
      ]}
      columnOptionRender={(item) => [
        <Popconfirm
          key="release"
          title={item?.status === 0 ? '确定要发布吗?' : '确定要取消发布吗?'}
          onConfirm={() => onRelease(item)}
          okText="确定"
          cancelText="取消"
        >
          <Button
            key="3"
            type="link"
          >
            状态
          </Button>
        </Popconfirm>
      ]}
    />
  )
}